@@ -1,6 +1,6 @@
 
 #############################################################################
-calcSVD <- function(X, r=2, eta=10, itmax=200, err=1e-8, mySeed=50) {
+calcSVD <- function(X, r=2, eta=10, q=2, itmax=200, err=1e-8, mySeed=50) {
     d <- ncol(X)
 
     # Initial random orthonormal matrix
@@ -9,9 +9,13 @@ calcSVD <- function(X, r=2, eta=10, itmax=200, err=1e-8, mySeed=50) {
     res <- mGSc(w, d, r)
     wp <- matrix(res$wp, ncol = r)
 
-    # power 2 symmetric matrix to use in the iterative search
-    t1 <- diag(c(rep(1,d))) + eta*t(X) %*% X
-    tt <- t1 %*% t1
+    # power q of the symmetric matrix to use in the iterative search
+    imd <- diag(c(rep(1,d)))
+    xtx <- t(X) %*% X
+    t1 <-  xtx %*% xtx
+    if (q>4 | q<=2) { tt <- imd + eta*t1 }
+    else if (q==3) { tt <- imd + eta*t1 %*% xtx }
+    else {  tt <- imd + eta*t1 %*% t1 }
 
     # calculation of the eigenvectors matrix
     res <- eigenVc(tt, wp, d, r, itmax, err)
